# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/redis/v1/cluster_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/redis/v1/cluster_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.mdb.redis.v1 import backup_pb2 as yandex_dot_cloud_dot_mdb_dot_redis_dot_v1_dot_backup__pb2
from yandex.cloud.mdb.redis.v1 import cluster_pb2 as yandex_dot_cloud_dot_mdb_dot_redis_dot_v1_dot_cluster__pb2
from yandex.cloud.mdb.redis.v1.config import redis_pb2 as yandex_dot_cloud_dot_mdb_dot_redis_dot_v1_dot_config_dot_redis__pb2
from yandex.cloud.mdb.redis.v1.config import redis5_0_pb2 as yandex_dot_cloud_dot_mdb_dot_redis_dot_v1_dot_config_dot_redis5__0__pb2
from yandex.cloud.mdb.redis.v1.config import redis6_0_pb2 as yandex_dot_cloud_dot_mdb_dot_redis_dot_v1_dot_config_dot_redis6__0__pb2
from yandex.cloud.mdb.redis.v1.config import redis6_2_pb2 as yandex_dot_cloud_dot_mdb_dot_redis_dot_v1_dot_config_dot_redis6__2__pb2
from yandex.cloud.mdb.redis.v1.config import redis7_0_pb2 as yandex_dot_cloud_dot_mdb_dot_redis_dot_v1_dot_config_dot_redis7__0__pb2
from yandex.cloud.mdb.redis.v1 import maintenance_pb2 as yandex_dot_cloud_dot_mdb_dot_redis_dot_v1_dot_maintenance__pb2
from yandex.cloud.mdb.redis.v1 import user_pb2 as yandex_dot_cloud_dot_mdb_dot_redis_dot_v1_dot_user__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/mdb/redis/v1/cluster_service.proto\x12\x19yandex.cloud.mdb.redis.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/type/timeofday.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/mdb/redis/v1/backup.proto\x1a\'yandex/cloud/mdb/redis/v1/cluster.proto\x1a,yandex/cloud/mdb/redis/v1/config/redis.proto\x1a/yandex/cloud/mdb/redis/v1/config/redis5_0.proto\x1a/yandex/cloud/mdb/redis/v1/config/redis6_0.proto\x1a/yandex/cloud/mdb/redis/v1/config/redis6_2.proto\x1a/yandex/cloud/mdb/redis/v1/config/redis7_0.proto\x1a+yandex/cloud/mdb/redis/v1/maintenance.proto\x1a$yandex/cloud/mdb/redis/v1/user.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"3\n\x1d\x45nableShardingClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"@\n\x1c\x45nableShardingClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"5\n\x11GetClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x13ListClustersRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"e\n\x14ListClustersResponse\x12\x34\n\x08\x63lusters\x18\x01 \x03(\x0b\x32\".yandex.cloud.mdb.redis.v1.Cluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xbd\x07\n\x14\x43reateClusterRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x88\x01\n\x06labels\x18\x04 \x03(\x0b\x32;.yandex.cloud.mdb.redis.v1.CreateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12I\n\x0b\x65nvironment\x18\x05 \x01(\x0e\x32..yandex.cloud.mdb.redis.v1.Cluster.EnvironmentB\x04\xe8\xc7\x31\x01\x12@\n\x0b\x63onfig_spec\x18\x06 \x01(\x0b\x32%.yandex.cloud.mdb.redis.v1.ConfigSpecB\x04\xe8\xc7\x31\x01\x12?\n\nhost_specs\x18\x07 \x03(\x0b\x32#.yandex.cloud.mdb.redis.v1.HostSpecB\x06\x82\xc8\x31\x02>0\x12 \n\nnetwork_id\x18\n \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x0f\n\x07sharded\x18\x0b \x01(\x08\x12\x1a\n\x12security_group_ids\x18\x0c \x03(\t\x12/\n\x0btls_enabled\x18\r \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1b\n\x13\x64\x65letion_protection\x18\x0e \x01(\x08\x12L\n\x10persistence_mode\x18\x0f \x01(\x0e\x32\x32.yandex.cloud.mdb.redis.v1.Cluster.PersistenceMode\x12\x1a\n\x12\x61nnounce_hostnames\x18\x10 \x01(\x08\x12H\n\x12maintenance_window\x18\x11 \x01(\x0b\x32,.yandex.cloud.mdb.redis.v1.MaintenanceWindow\x12@\n\nuser_specs\x18\x12 \x03(\x0b\x32#.yandex.cloud.mdb.redis.v1.UserSpecB\x07\x82\xc8\x31\x03>=0\x12\x15\n\rauth_sentinel\x18\x13 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x08\x10\n\"+\n\x15\x43reateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xcb\x05\n\x14UpdateClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x88\x01\n\x06labels\x18\x04 \x03(\x0b\x32;.yandex.cloud.mdb.redis.v1.UpdateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12:\n\x0b\x63onfig_spec\x18\x05 \x01(\x0b\x32%.yandex.cloud.mdb.redis.v1.ConfigSpec\x12(\n\x04name\x18\x06 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12H\n\x12maintenance_window\x18\x07 \x01(\x0b\x32,.yandex.cloud.mdb.redis.v1.MaintenanceWindow\x12\x1a\n\x12security_group_ids\x18\x08 \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\t \x01(\x08\x12L\n\x10persistence_mode\x18\n \x01(\x0e\x32\x32.yandex.cloud.mdb.redis.v1.Cluster.PersistenceMode\x12\x1c\n\nnetwork_id\x18\x0b \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1a\n\x12\x61nnounce_hostnames\x18\x0c \x01(\x08\x12\x15\n\rauth_sentinel\x18\r \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15UpdateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"7\n\x13StartClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"*\n\x14StartClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"6\n\x12StopClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13StopClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"c\n\x12MoveClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"b\n\x13MoveClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x18\n\x10source_folder_id\x18\x02 \x01(\t\x12\x1d\n\x15\x64\x65stination_folder_id\x18\x03 \x01(\t\"\x8b\x01\n\x19UpdateClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12L\n\x11update_host_specs\x18\x02 \x03(\x0b\x32).yandex.cloud.mdb.redis.v1.UpdateHostSpecB\x06\x82\xc8\x31\x02>0\"D\n\x1aUpdateClusterHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"8\n\x14\x42\x61\x63kupClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x42\x61\x63kupClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xfb\x06\n\x15RestoreClusterRequest\x12\x17\n\tbackup_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x89\x01\n\x06labels\x18\x04 \x03(\x0b\x32<.yandex.cloud.mdb.redis.v1.RestoreClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12I\n\x0b\x65nvironment\x18\x05 \x01(\x0e\x32..yandex.cloud.mdb.redis.v1.Cluster.EnvironmentB\x04\xe8\xc7\x31\x01\x12@\n\x0b\x63onfig_spec\x18\x06 \x01(\x0b\x32%.yandex.cloud.mdb.redis.v1.ConfigSpecB\x04\xe8\xc7\x31\x01\x12?\n\nhost_specs\x18\x07 \x03(\x0b\x32#.yandex.cloud.mdb.redis.v1.HostSpecB\x06\x82\xc8\x31\x02>0\x12 \n\nnetwork_id\x18\x08 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1b\n\tfolder_id\x18\t \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1a\n\x12security_group_ids\x18\n \x03(\t\x12/\n\x0btls_enabled\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12L\n\x10persistence_mode\x18\x0c \x01(\x0e\x32\x32.yandex.cloud.mdb.redis.v1.Cluster.PersistenceMode\x12\x1b\n\x13\x64\x65letion_protection\x18\r \x01(\x08\x12\x1a\n\x12\x61nnounce_hostnames\x18\x0e \x01(\x08\x12H\n\x12maintenance_window\x18\x0f \x01(\x0b\x32,.yandex.cloud.mdb.redis.v1.MaintenanceWindow\x12\x15\n\rauth_sentinel\x18\x10 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"?\n\x16RestoreClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tbackup_id\x18\x02 \x01(\t\"^\n\x1bStartClusterFailoverRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\nhost_names\x18\x02 \x03(\tB\t\x8a\xc8\x31\x05<=253\"F\n\x1cStartClusterFailoverMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"\xca\x02\n\x1cRescheduleMaintenanceRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x65\n\x0freschedule_type\x18\x02 \x01(\x0e\x32\x46.yandex.cloud.mdb.redis.v1.RescheduleMaintenanceRequest.RescheduleTypeB\x04\xe8\xc7\x31\x01\x12\x31\n\rdelayed_until\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"n\n\x0eRescheduleType\x12\x1f\n\x1bRESCHEDULE_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tIMMEDIATE\x10\x01\x12\x19\n\x15NEXT_AVAILABLE_WINDOW\x10\x02\x12\x11\n\rSPECIFIC_TIME\x10\x03\"l\n\x1dRescheduleMaintenanceMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x31\n\rdelayed_until\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampJ\x04\x08\x02\x10\x04\"\xae\x01\n\tLogRecord\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x42\n\x07message\x18\x02 \x03(\x0b\x32\x31.yandex.cloud.mdb.redis.v1.LogRecord.MessageEntry\x1a.\n\x0cMessageEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf8\x02\n\x16ListClusterLogsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\rcolumn_filter\x18\x02 \x03(\t\x12S\n\x0cservice_type\x18\x03 \x01(\x0e\x32=.yandex.cloud.mdb.redis.v1.ListClusterLogsRequest.ServiceType\x12-\n\tfrom_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\tpage_size\x18\x06 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=100\"6\n\x0bServiceType\x12\x1c\n\x18SERVICE_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05REDIS\x10\x01\"f\n\x17ListClusterLogsResponse\x12\x32\n\x04logs\x18\x01 \x03(\x0b\x32$.yandex.cloud.mdb.redis.v1.LogRecord\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"b\n\x0fStreamLogRecord\x12\x34\n\x06record\x18\x01 \x01(\x0b\x32$.yandex.cloud.mdb.redis.v1.LogRecord\x12\x19\n\x11next_record_token\x18\x02 \x01(\t\"\xfb\x02\n\x18StreamClusterLogsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\rcolumn_filter\x18\x02 \x03(\t\x12U\n\x0cservice_type\x18\x03 \x01(\x0e\x32?.yandex.cloud.mdb.redis.v1.StreamClusterLogsRequest.ServiceType\x12-\n\tfrom_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1f\n\x0crecord_token\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x07 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"6\n\x0bServiceType\x12\x1c\n\x18SERVICE_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05REDIS\x10\x01\"~\n\x1cListClusterOperationsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"o\n\x1dListClusterOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"{\n\x19ListClusterBackupsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"i\n\x1aListClusterBackupsResponse\x12\x32\n\x07\x62\x61\x63kups\x18\x01 \x03(\x0b\x32!.yandex.cloud.mdb.redis.v1.Backup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"y\n\x17ListClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"c\n\x18ListClusterHostsResponse\x12.\n\x05hosts\x18\x01 \x03(\x0b\x32\x1f.yandex.cloud.mdb.redis.v1.Host\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"{\n\x16\x41\x64\x64\x43lusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12?\n\nhost_specs\x18\x02 \x03(\x0b\x32#.yandex.cloud.mdb.redis.v1.HostSpecB\x06\x82\xc8\x31\x02>0\"A\n\x17\x41\x64\x64\x43lusterHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"b\n\x19\x44\x65leteClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\nhost_names\x18\x02 \x03(\tB\x0f\x82\xc8\x31\x02>0\x8a\xc8\x31\x05<=253\"D\n\x1a\x44\x65leteClusterHostsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nhost_names\x18\x02 \x03(\t\"n\n\x16GetClusterShardRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\nshard_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\"z\n\x18ListClusterShardsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"f\n\x19ListClusterShardsResponse\x12\x30\n\x06shards\x18\x01 \x03(\x0b\x32 .yandex.cloud.mdb.redis.v1.Shard\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xb5\x01\n\x16\x41\x64\x64\x43lusterShardRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\nshard_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12?\n\nhost_specs\x18\x04 \x03(\x0b\x32#.yandex.cloud.mdb.redis.v1.HostSpecB\x06\x82\xc8\x31\x02>0J\x04\x08\x03\x10\x04\"A\n\x17\x41\x64\x64\x43lusterShardMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nshard_name\x18\x02 \x01(\t\"q\n\x19\x44\x65leteClusterShardRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\nshard_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\"D\n\x1a\x44\x65leteClusterShardMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x12\n\nshard_name\x18\x02 \x01(\t\";\n\x17RebalanceClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\".\n\x18RebalanceClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xab\x01\n\x0eUpdateHostSpec\x12\x17\n\thost_name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x35\n\x10replica_priority\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x18\n\x10\x61ssign_public_ip\x18\x03 \x01(\x08\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\xaf\x01\n\x08HostSpec\x12\x0f\n\x07zone_id\x18\x01 \x01(\t\x12\x11\n\tsubnet_id\x18\x02 \x01(\t\x12.\n\nshard_name\x18\x03 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x35\n\x10replica_priority\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x18\n\x10\x61ssign_public_ip\x18\x05 \x01(\x08\"\x9b\x06\n\nConfigSpec\x12\x0f\n\x07version\x18\x01 \x01(\t\x12]\n\x10redis_config_5_0\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.mdb.redis.v1.config.RedisConfig5_0H\x00R\x0fredisConfig_5_0\x12]\n\x10redis_config_6_0\x18\x06 \x01(\x0b\x32\x30.yandex.cloud.mdb.redis.v1.config.RedisConfig6_0H\x00R\x0fredisConfig_6_0\x12]\n\x10redis_config_6_2\x18\x07 \x01(\x0b\x32\x30.yandex.cloud.mdb.redis.v1.config.RedisConfig6_2H\x00R\x0fredisConfig_6_2\x12]\n\x10redis_config_7_0\x18\x08 \x01(\x0b\x32\x30.yandex.cloud.mdb.redis.v1.config.RedisConfig7_0H\x00R\x0fredisConfig_7_0\x12\x37\n\tresources\x18\x03 \x01(\x0b\x32$.yandex.cloud.mdb.redis.v1.Resources\x12\x33\n\x13\x62\x61\x63kup_window_start\x18\x04 \x01(\x0b\x32\x16.google.type.TimeOfDay\x12\x31\n\x06\x61\x63\x63\x65ss\x18\x05 \x01(\x0b\x32!.yandex.cloud.mdb.redis.v1.Access\x12<\n\x05redis\x18\x0b \x01(\x0b\x32-.yandex.cloud.mdb.redis.v1.config.RedisConfig\x12M\n\x15\x64isk_size_autoscaling\x18\x0c \x01(\x0b\x32..yandex.cloud.mdb.redis.v1.DiskSizeAutoscaling\x12>\n\x19\x62\x61\x63kup_retain_period_days\x18\r \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\n\nredis_specJ\x04\x08\t\x10\x0b\x32\xed&\n\x0e\x43lusterService\x12\x88\x01\n\x03Get\x12,.yandex.cloud.mdb.redis.v1.GetClusterRequest\x1a\".yandex.cloud.mdb.redis.v1.Cluster\"/\x82\xd3\xe4\x93\x02)\x12\'/managed-redis/v1/clusters/{cluster_id}\x12\x8b\x01\n\x04List\x12..yandex.cloud.mdb.redis.v1.ListClustersRequest\x1a/.yandex.cloud.mdb.redis.v1.ListClustersResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/managed-redis/v1/clusters\x12\xa7\x01\n\x06\x43reate\x12/.yandex.cloud.mdb.redis.v1.CreateClusterRequest\x1a!.yandex.cloud.operation.Operation\"I\xb2\xd2* \n\x15\x43reateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x1f\"\x1a/managed-redis/v1/clusters:\x01*\x12\xb4\x01\n\x06Update\x12/.yandex.cloud.mdb.redis.v1.UpdateClusterRequest\x1a!.yandex.cloud.operation.Operation\"V\xb2\xd2* \n\x15UpdateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02,2\'/managed-redis/v1/clusters/{cluster_id}:\x01*\x12\xbf\x01\n\x06\x44\x65lete\x12/.yandex.cloud.mdb.redis.v1.DeleteClusterRequest\x1a!.yandex.cloud.operation.Operation\"a\xb2\xd2*.\n\x15\x44\x65leteClusterMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02)*\'/managed-redis/v1/clusters/{cluster_id}\x12\xb4\x01\n\x05Start\x12..yandex.cloud.mdb.redis.v1.StartClusterRequest\x1a!.yandex.cloud.operation.Operation\"X\xb2\xd2*\x1f\n\x14StartClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02/\"-/managed-redis/v1/clusters/{cluster_id}:start\x12\xb0\x01\n\x04Stop\x12-.yandex.cloud.mdb.redis.v1.StopClusterRequest\x1a!.yandex.cloud.operation.Operation\"V\xb2\xd2*\x1e\n\x13StopClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02.\",/managed-redis/v1/clusters/{cluster_id}:stop\x12\xb3\x01\n\x04Move\x12-.yandex.cloud.mdb.redis.v1.MoveClusterRequest\x1a!.yandex.cloud.operation.Operation\"Y\xb2\xd2*\x1e\n\x13MoveClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x31\",/managed-redis/v1/clusters/{cluster_id}:move:\x01*\x12\xb8\x01\n\x06\x42\x61\x63kup\x12/.yandex.cloud.mdb.redis.v1.BackupClusterRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2* \n\x15\x42\x61\x63kupClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x30\"./managed-redis/v1/clusters/{cluster_id}:backup\x12\xb2\x01\n\x07Restore\x12\x30.yandex.cloud.mdb.redis.v1.RestoreClusterRequest\x1a!.yandex.cloud.operation.Operation\"R\xb2\xd2*!\n\x16RestoreClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\'\"\"/managed-redis/v1/clusters:restore:\x01*\x12\xe9\x01\n\x15RescheduleMaintenance\x12\x37.yandex.cloud.mdb.redis.v1.RescheduleMaintenanceRequest\x1a!.yandex.cloud.operation.Operation\"t\xb2\xd2*(\n\x1dRescheduleMaintenanceMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x42\"=/managed-redis/v1/clusters/{cluster_id}:rescheduleMaintenance:\x01*\x12\xd7\x01\n\rStartFailover\x12\x36.yandex.cloud.mdb.redis.v1.StartClusterFailoverRequest\x1a!.yandex.cloud.operation.Operation\"k\xb2\xd2*\'\n\x1cStartClusterFailoverMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02:\"5/managed-redis/v1/clusters/{cluster_id}:startFailover:\x01*\x12\xa7\x01\n\x08ListLogs\x12\x31.yandex.cloud.mdb.redis.v1.ListClusterLogsRequest\x1a\x32.yandex.cloud.mdb.redis.v1.ListClusterLogsResponse\"4\x82\xd3\xe4\x93\x02.\x12,/managed-redis/v1/clusters/{cluster_id}:logs\x12\xac\x01\n\nStreamLogs\x12\x33.yandex.cloud.mdb.redis.v1.StreamClusterLogsRequest\x1a*.yandex.cloud.mdb.redis.v1.StreamLogRecord\";\x82\xd3\xe4\x93\x02\x35\x12\x33/managed-redis/v1/clusters/{cluster_id}:stream_logs0\x01\x12\xbf\x01\n\x0eListOperations\x12\x37.yandex.cloud.mdb.redis.v1.ListClusterOperationsRequest\x1a\x38.yandex.cloud.mdb.redis.v1.ListClusterOperationsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/managed-redis/v1/clusters/{cluster_id}/operations\x12\xb3\x01\n\x0bListBackups\x12\x34.yandex.cloud.mdb.redis.v1.ListClusterBackupsRequest\x1a\x35.yandex.cloud.mdb.redis.v1.ListClusterBackupsResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//managed-redis/v1/clusters/{cluster_id}/backups\x12\xab\x01\n\tListHosts\x12\x32.yandex.cloud.mdb.redis.v1.ListClusterHostsRequest\x1a\x33.yandex.cloud.mdb.redis.v1.ListClusterHostsResponse\"5\x82\xd3\xe4\x93\x02/\x12-/managed-redis/v1/clusters/{cluster_id}/hosts\x12\xda\x01\n\x08\x41\x64\x64Hosts\x12\x31.yandex.cloud.mdb.redis.v1.AddClusterHostsRequest\x1a!.yandex.cloud.operation.Operation\"x\xb2\xd2*0\n\x17\x41\x64\x64\x43lusterHostsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02>\"9/managed-redis/v1/clusters/{cluster_id}/hosts:batchCreate:\x01*\x12\xe3\x01\n\x0b\x44\x65leteHosts\x12\x34.yandex.cloud.mdb.redis.v1.DeleteClusterHostsRequest\x1a!.yandex.cloud.operation.Operation\"{\xb2\xd2*3\n\x1a\x44\x65leteClusterHostsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02>\"9/managed-redis/v1/clusters/{cluster_id}/hosts:batchDelete:\x01*\x12\xe3\x01\n\x0bUpdateHosts\x12\x34.yandex.cloud.mdb.redis.v1.UpdateClusterHostsRequest\x1a!.yandex.cloud.operation.Operation\"{\xb2\xd2*3\n\x1aUpdateClusterHostsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02>\"9/managed-redis/v1/clusters/{cluster_id}/hosts:batchUpdate:\x01*\x12\xa4\x01\n\x08GetShard\x12\x31.yandex.cloud.mdb.redis.v1.GetClusterShardRequest\x1a .yandex.cloud.mdb.redis.v1.Shard\"C\x82\xd3\xe4\x93\x02=\x12;/managed-redis/v1/clusters/{cluster_id}/shards/{shard_name}\x12\xaf\x01\n\nListShards\x12\x33.yandex.cloud.mdb.redis.v1.ListClusterShardsRequest\x1a\x34.yandex.cloud.mdb.redis.v1.ListClusterShardsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./managed-redis/v1/clusters/{cluster_id}/shards\x12\xbf\x01\n\x08\x41\x64\x64Shard\x12\x31.yandex.cloud.mdb.redis.v1.AddClusterShardRequest\x1a!.yandex.cloud.operation.Operation\"]\xb2\xd2* \n\x17\x41\x64\x64\x43lusterShardMetadata\x12\x05Shard\x82\xd3\xe4\x93\x02\x33\"./managed-redis/v1/clusters/{cluster_id}/shards:\x01*\x12\xe2\x01\n\x0b\x44\x65leteShard\x12\x34.yandex.cloud.mdb.redis.v1.DeleteClusterShardRequest\x1a!.yandex.cloud.operation.Operation\"z\xb2\xd2*3\n\x1a\x44\x65leteClusterShardMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02=*;/managed-redis/v1/clusters/{cluster_id}/shards/{shard_name}\x12\xc4\x01\n\tRebalance\x12\x32.yandex.cloud.mdb.redis.v1.RebalanceClusterRequest\x1a!.yandex.cloud.operation.Operation\"`\xb2\xd2*#\n\x18RebalanceClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x33\"1/managed-redis/v1/clusters/{cluster_id}:rebalance\x12\xd9\x01\n\x0e\x45nableSharding\x12\x37.yandex.cloud.mdb.redis.v1.EnableShardingClusterRequest\x1a!.yandex.cloud.operation.Operation\"k\xb2\xd2*(\n\x1d\x45nableShardingClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x39\"7/managed-redis/v1/clusters/{cluster_id}:enable_shardingBd\n\x1dyandex.cloud.api.mdb.redis.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/redis/v1;redisb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.redis.v1.cluster_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035yandex.cloud.api.mdb.redis.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/redis/v1;redis'
  _globals['_ENABLESHARDINGCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_ENABLESHARDINGCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['environment']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['environment']._serialized_options = b'\350\3071\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['config_spec']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['config_spec']._serialized_options = b'\350\3071\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['host_specs']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['host_specs']._serialized_options = b'\202\3101\002>0'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['user_specs']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['user_specs']._serialized_options = b'\202\3101\003>=0'
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['network_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STARTCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STARTCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STOPCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STOPCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_MOVECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_MOVECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_MOVECLUSTERREQUEST'].fields_by_name['destination_folder_id']._loaded_options = None
  _globals['_MOVECLUSTERREQUEST'].fields_by_name['destination_folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATECLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECLUSTERHOSTSREQUEST'].fields_by_name['update_host_specs']._loaded_options = None
  _globals['_UPDATECLUSTERHOSTSREQUEST'].fields_by_name['update_host_specs']._serialized_options = b'\202\3101\002>0'
  _globals['_BACKUPCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_BACKUPCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['backup_id']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['backup_id']._serialized_options = b'\350\3071\001'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['environment']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['environment']._serialized_options = b'\350\3071\001'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['config_spec']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['config_spec']._serialized_options = b'\350\3071\001'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['host_specs']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['host_specs']._serialized_options = b'\202\3101\002>0'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_RESTORECLUSTERREQUEST'].fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_STARTCLUSTERFAILOVERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STARTCLUSTERFAILOVERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STARTCLUSTERFAILOVERREQUEST'].fields_by_name['host_names']._loaded_options = None
  _globals['_STARTCLUSTERFAILOVERREQUEST'].fields_by_name['host_names']._serialized_options = b'\212\3101\005<=253'
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['reschedule_type']._loaded_options = None
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['reschedule_type']._serialized_options = b'\350\3071\001'
  _globals['_LOGRECORD_MESSAGEENTRY']._loaded_options = None
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_options = b'8\001'
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERLOGSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['record_token']._loaded_options = None
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['record_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_STREAMCLUSTERLOGSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTEROPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERBACKUPSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERHOSTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_ADDCLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_ADDCLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ADDCLUSTERHOSTSREQUEST'].fields_by_name['host_specs']._loaded_options = None
  _globals['_ADDCLUSTERHOSTSREQUEST'].fields_by_name['host_specs']._serialized_options = b'\202\3101\002>0'
  _globals['_DELETECLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECLUSTERHOSTSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETECLUSTERHOSTSREQUEST'].fields_by_name['host_names']._loaded_options = None
  _globals['_DELETECLUSTERHOSTSREQUEST'].fields_by_name['host_names']._serialized_options = b'\202\3101\002>0\212\3101\005<=253'
  _globals['_GETCLUSTERSHARDREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETCLUSTERSHARDREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETCLUSTERSHARDREQUEST'].fields_by_name['shard_name']._loaded_options = None
  _globals['_GETCLUSTERSHARDREQUEST'].fields_by_name['shard_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_LISTCLUSTERSHARDSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTERSHARDSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERSHARDSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTERSHARDSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTERSHARDSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTERSHARDSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_ADDCLUSTERSHARDREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_ADDCLUSTERSHARDREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ADDCLUSTERSHARDREQUEST'].fields_by_name['shard_name']._loaded_options = None
  _globals['_ADDCLUSTERSHARDREQUEST'].fields_by_name['shard_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_ADDCLUSTERSHARDREQUEST'].fields_by_name['host_specs']._loaded_options = None
  _globals['_ADDCLUSTERSHARDREQUEST'].fields_by_name['host_specs']._serialized_options = b'\202\3101\002>0'
  _globals['_DELETECLUSTERSHARDREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECLUSTERSHARDREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETECLUSTERSHARDREQUEST'].fields_by_name['shard_name']._loaded_options = None
  _globals['_DELETECLUSTERSHARDREQUEST'].fields_by_name['shard_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_REBALANCECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_REBALANCECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEHOSTSPEC'].fields_by_name['host_name']._loaded_options = None
  _globals['_UPDATEHOSTSPEC'].fields_by_name['host_name']._serialized_options = b'\350\3071\001'
  _globals['_HOSTSPEC'].fields_by_name['shard_name']._loaded_options = None
  _globals['_HOSTSPEC'].fields_by_name['shard_name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_CLUSTERSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002)\022\'/managed-redis/v1/clusters/{cluster_id}'
  _globals['_CLUSTERSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\034\022\032/managed-redis/v1/clusters'
  _globals['_CLUSTERSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateClusterMetadata\022\007Cluster\202\323\344\223\002\037\"\032/managed-redis/v1/clusters:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateClusterMetadata\022\007Cluster\202\323\344\223\002,2\'/managed-redis/v1/clusters/{cluster_id}:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteClusterMetadata\022\025google.protobuf.Empty\202\323\344\223\002)*\'/managed-redis/v1/clusters/{cluster_id}'
  _globals['_CLUSTERSERVICE'].methods_by_name['Start']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Start']._serialized_options = b'\262\322*\037\n\024StartClusterMetadata\022\007Cluster\202\323\344\223\002/\"-/managed-redis/v1/clusters/{cluster_id}:start'
  _globals['_CLUSTERSERVICE'].methods_by_name['Stop']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Stop']._serialized_options = b'\262\322*\036\n\023StopClusterMetadata\022\007Cluster\202\323\344\223\002.\",/managed-redis/v1/clusters/{cluster_id}:stop'
  _globals['_CLUSTERSERVICE'].methods_by_name['Move']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Move']._serialized_options = b'\262\322*\036\n\023MoveClusterMetadata\022\007Cluster\202\323\344\223\0021\",/managed-redis/v1/clusters/{cluster_id}:move:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Backup']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Backup']._serialized_options = b'\262\322* \n\025BackupClusterMetadata\022\007Cluster\202\323\344\223\0020\"./managed-redis/v1/clusters/{cluster_id}:backup'
  _globals['_CLUSTERSERVICE'].methods_by_name['Restore']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Restore']._serialized_options = b'\262\322*!\n\026RestoreClusterMetadata\022\007Cluster\202\323\344\223\002\'\"\"/managed-redis/v1/clusters:restore:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['RescheduleMaintenance']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['RescheduleMaintenance']._serialized_options = b'\262\322*(\n\035RescheduleMaintenanceMetadata\022\007Cluster\202\323\344\223\002B\"=/managed-redis/v1/clusters/{cluster_id}:rescheduleMaintenance:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['StartFailover']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['StartFailover']._serialized_options = b'\262\322*\'\n\034StartClusterFailoverMetadata\022\007Cluster\202\323\344\223\002:\"5/managed-redis/v1/clusters/{cluster_id}:startFailover:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListLogs']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListLogs']._serialized_options = b'\202\323\344\223\002.\022,/managed-redis/v1/clusters/{cluster_id}:logs'
  _globals['_CLUSTERSERVICE'].methods_by_name['StreamLogs']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['StreamLogs']._serialized_options = b'\202\323\344\223\0025\0223/managed-redis/v1/clusters/{cluster_id}:stream_logs'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0024\0222/managed-redis/v1/clusters/{cluster_id}/operations'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListBackups']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListBackups']._serialized_options = b'\202\323\344\223\0021\022//managed-redis/v1/clusters/{cluster_id}/backups'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListHosts']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListHosts']._serialized_options = b'\202\323\344\223\002/\022-/managed-redis/v1/clusters/{cluster_id}/hosts'
  _globals['_CLUSTERSERVICE'].methods_by_name['AddHosts']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['AddHosts']._serialized_options = b'\262\322*0\n\027AddClusterHostsMetadata\022\025google.protobuf.Empty\202\323\344\223\002>\"9/managed-redis/v1/clusters/{cluster_id}/hosts:batchCreate:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteHosts']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteHosts']._serialized_options = b'\262\322*3\n\032DeleteClusterHostsMetadata\022\025google.protobuf.Empty\202\323\344\223\002>\"9/managed-redis/v1/clusters/{cluster_id}/hosts:batchDelete:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['UpdateHosts']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['UpdateHosts']._serialized_options = b'\262\322*3\n\032UpdateClusterHostsMetadata\022\025google.protobuf.Empty\202\323\344\223\002>\"9/managed-redis/v1/clusters/{cluster_id}/hosts:batchUpdate:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['GetShard']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['GetShard']._serialized_options = b'\202\323\344\223\002=\022;/managed-redis/v1/clusters/{cluster_id}/shards/{shard_name}'
  _globals['_CLUSTERSERVICE'].methods_by_name['ListShards']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['ListShards']._serialized_options = b'\202\323\344\223\0020\022./managed-redis/v1/clusters/{cluster_id}/shards'
  _globals['_CLUSTERSERVICE'].methods_by_name['AddShard']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['AddShard']._serialized_options = b'\262\322* \n\027AddClusterShardMetadata\022\005Shard\202\323\344\223\0023\"./managed-redis/v1/clusters/{cluster_id}/shards:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteShard']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['DeleteShard']._serialized_options = b'\262\322*3\n\032DeleteClusterShardMetadata\022\025google.protobuf.Empty\202\323\344\223\002=*;/managed-redis/v1/clusters/{cluster_id}/shards/{shard_name}'
  _globals['_CLUSTERSERVICE'].methods_by_name['Rebalance']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Rebalance']._serialized_options = b'\262\322*#\n\030RebalanceClusterMetadata\022\007Cluster\202\323\344\223\0023\"1/managed-redis/v1/clusters/{cluster_id}:rebalance'
  _globals['_CLUSTERSERVICE'].methods_by_name['EnableSharding']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['EnableSharding']._serialized_options = b'\262\322*(\n\035EnableShardingClusterMetadata\022\007Cluster\202\323\344\223\0029\"7/managed-redis/v1/clusters/{cluster_id}:enable_sharding'
  _globals['_ENABLESHARDINGCLUSTERMETADATA']._serialized_start=747
  _globals['_ENABLESHARDINGCLUSTERMETADATA']._serialized_end=798
  _globals['_ENABLESHARDINGCLUSTERREQUEST']._serialized_start=800
  _globals['_ENABLESHARDINGCLUSTERREQUEST']._serialized_end=864
  _globals['_GETCLUSTERREQUEST']._serialized_start=866
  _globals['_GETCLUSTERREQUEST']._serialized_end=919
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=922
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=1066
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=1068
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=1169
  _globals['_CREATECLUSTERREQUEST']._serialized_start=1172
  _globals['_CREATECLUSTERREQUEST']._serialized_end=2129
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_start=2078
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_end=2123
  _globals['_CREATECLUSTERMETADATA']._serialized_start=2131
  _globals['_CREATECLUSTERMETADATA']._serialized_end=2174
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=2177
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=2892
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_start=2078
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_end=2123
  _globals['_UPDATECLUSTERMETADATA']._serialized_start=2894
  _globals['_UPDATECLUSTERMETADATA']._serialized_end=2937
  _globals['_DELETECLUSTERREQUEST']._serialized_start=2939
  _globals['_DELETECLUSTERREQUEST']._serialized_end=2995
  _globals['_DELETECLUSTERMETADATA']._serialized_start=2997
  _globals['_DELETECLUSTERMETADATA']._serialized_end=3040
  _globals['_STARTCLUSTERREQUEST']._serialized_start=3042
  _globals['_STARTCLUSTERREQUEST']._serialized_end=3097
  _globals['_STARTCLUSTERMETADATA']._serialized_start=3099
  _globals['_STARTCLUSTERMETADATA']._serialized_end=3141
  _globals['_STOPCLUSTERREQUEST']._serialized_start=3143
  _globals['_STOPCLUSTERREQUEST']._serialized_end=3197
  _globals['_STOPCLUSTERMETADATA']._serialized_start=3199
  _globals['_STOPCLUSTERMETADATA']._serialized_end=3240
  _globals['_MOVECLUSTERREQUEST']._serialized_start=3242
  _globals['_MOVECLUSTERREQUEST']._serialized_end=3341
  _globals['_MOVECLUSTERMETADATA']._serialized_start=3343
  _globals['_MOVECLUSTERMETADATA']._serialized_end=3441
  _globals['_UPDATECLUSTERHOSTSREQUEST']._serialized_start=3444
  _globals['_UPDATECLUSTERHOSTSREQUEST']._serialized_end=3583
  _globals['_UPDATECLUSTERHOSTSMETADATA']._serialized_start=3585
  _globals['_UPDATECLUSTERHOSTSMETADATA']._serialized_end=3653
  _globals['_BACKUPCLUSTERREQUEST']._serialized_start=3655
  _globals['_BACKUPCLUSTERREQUEST']._serialized_end=3711
  _globals['_BACKUPCLUSTERMETADATA']._serialized_start=3713
  _globals['_BACKUPCLUSTERMETADATA']._serialized_end=3756
  _globals['_RESTORECLUSTERREQUEST']._serialized_start=3759
  _globals['_RESTORECLUSTERREQUEST']._serialized_end=4650
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_start=2078
  _globals['_RESTORECLUSTERREQUEST_LABELSENTRY']._serialized_end=2123
  _globals['_RESTORECLUSTERMETADATA']._serialized_start=4652
  _globals['_RESTORECLUSTERMETADATA']._serialized_end=4715
  _globals['_STARTCLUSTERFAILOVERREQUEST']._serialized_start=4717
  _globals['_STARTCLUSTERFAILOVERREQUEST']._serialized_end=4811
  _globals['_STARTCLUSTERFAILOVERMETADATA']._serialized_start=4813
  _globals['_STARTCLUSTERFAILOVERMETADATA']._serialized_end=4883
  _globals['_RESCHEDULEMAINTENANCEREQUEST']._serialized_start=4886
  _globals['_RESCHEDULEMAINTENANCEREQUEST']._serialized_end=5216
  _globals['_RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE']._serialized_start=5106
  _globals['_RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE']._serialized_end=5216
  _globals['_RESCHEDULEMAINTENANCEMETADATA']._serialized_start=5218
  _globals['_RESCHEDULEMAINTENANCEMETADATA']._serialized_end=5326
  _globals['_LOGRECORD']._serialized_start=5329
  _globals['_LOGRECORD']._serialized_end=5503
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_start=5457
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_end=5503
  _globals['_LISTCLUSTERLOGSREQUEST']._serialized_start=5506
  _globals['_LISTCLUSTERLOGSREQUEST']._serialized_end=5882
  _globals['_LISTCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_start=5828
  _globals['_LISTCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_end=5882
  _globals['_LISTCLUSTERLOGSRESPONSE']._serialized_start=5884
  _globals['_LISTCLUSTERLOGSRESPONSE']._serialized_end=5986
  _globals['_STREAMLOGRECORD']._serialized_start=5988
  _globals['_STREAMLOGRECORD']._serialized_end=6086
  _globals['_STREAMCLUSTERLOGSREQUEST']._serialized_start=6089
  _globals['_STREAMCLUSTERLOGSREQUEST']._serialized_end=6468
  _globals['_STREAMCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_start=5828
  _globals['_STREAMCLUSTERLOGSREQUEST_SERVICETYPE']._serialized_end=5882
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_start=6470
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_end=6596
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_start=6598
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_end=6709
  _globals['_LISTCLUSTERBACKUPSREQUEST']._serialized_start=6711
  _globals['_LISTCLUSTERBACKUPSREQUEST']._serialized_end=6834
  _globals['_LISTCLUSTERBACKUPSRESPONSE']._serialized_start=6836
  _globals['_LISTCLUSTERBACKUPSRESPONSE']._serialized_end=6941
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_start=6943
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_end=7064
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_start=7066
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_end=7165
  _globals['_ADDCLUSTERHOSTSREQUEST']._serialized_start=7167
  _globals['_ADDCLUSTERHOSTSREQUEST']._serialized_end=7290
  _globals['_ADDCLUSTERHOSTSMETADATA']._serialized_start=7292
  _globals['_ADDCLUSTERHOSTSMETADATA']._serialized_end=7357
  _globals['_DELETECLUSTERHOSTSREQUEST']._serialized_start=7359
  _globals['_DELETECLUSTERHOSTSREQUEST']._serialized_end=7457
  _globals['_DELETECLUSTERHOSTSMETADATA']._serialized_start=7459
  _globals['_DELETECLUSTERHOSTSMETADATA']._serialized_end=7527
  _globals['_GETCLUSTERSHARDREQUEST']._serialized_start=7529
  _globals['_GETCLUSTERSHARDREQUEST']._serialized_end=7639
  _globals['_LISTCLUSTERSHARDSREQUEST']._serialized_start=7641
  _globals['_LISTCLUSTERSHARDSREQUEST']._serialized_end=7763
  _globals['_LISTCLUSTERSHARDSRESPONSE']._serialized_start=7765
  _globals['_LISTCLUSTERSHARDSRESPONSE']._serialized_end=7867
  _globals['_ADDCLUSTERSHARDREQUEST']._serialized_start=7870
  _globals['_ADDCLUSTERSHARDREQUEST']._serialized_end=8051
  _globals['_ADDCLUSTERSHARDMETADATA']._serialized_start=8053
  _globals['_ADDCLUSTERSHARDMETADATA']._serialized_end=8118
  _globals['_DELETECLUSTERSHARDREQUEST']._serialized_start=8120
  _globals['_DELETECLUSTERSHARDREQUEST']._serialized_end=8233
  _globals['_DELETECLUSTERSHARDMETADATA']._serialized_start=8235
  _globals['_DELETECLUSTERSHARDMETADATA']._serialized_end=8303
  _globals['_REBALANCECLUSTERREQUEST']._serialized_start=8305
  _globals['_REBALANCECLUSTERREQUEST']._serialized_end=8364
  _globals['_REBALANCECLUSTERMETADATA']._serialized_start=8366
  _globals['_REBALANCECLUSTERMETADATA']._serialized_end=8412
  _globals['_UPDATEHOSTSPEC']._serialized_start=8415
  _globals['_UPDATEHOSTSPEC']._serialized_end=8586
  _globals['_HOSTSPEC']._serialized_start=8589
  _globals['_HOSTSPEC']._serialized_end=8764
  _globals['_CONFIGSPEC']._serialized_start=8767
  _globals['_CONFIGSPEC']._serialized_end=9562
  _globals['_CLUSTERSERVICE']._serialized_start=9565
  _globals['_CLUSTERSERVICE']._serialized_end=14538
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/speechsense/v1/classifiers_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/speechsense/v1/classifiers_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.speechsense.v1 import classifier_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_classifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5yandex/cloud/speechsense/v1/classifiers_service.proto\x12\x1byandex.cloud.speechsense.v1\x1a\x1cgoogle/api/annotations.proto\x1a,yandex/cloud/speechsense/v1/classifier.proto\",\n\x16ListClassifiersRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"W\n\x17ListClassifiersResponse\x12<\n\x0b\x63lassifiers\x18\x01 \x03(\x0b\x32\'.yandex.cloud.speechsense.v1.Classifier2\xb5\x01\n\x12\x43lassifiersService\x12\x9e\x01\n\x04List\x12\x33.yandex.cloud.speechsense.v1.ListClassifiersRequest\x1a\x34.yandex.cloud.speechsense.v1.ListClassifiersResponse\"+\x82\xd3\xe4\x93\x02%\" /speechsense/v1/classifiers/list:\x01*B\x87\x01\n\x1fyandex.cloud.api.speechsense.v1B\x17\x43lassifiersServiceProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.classifiers_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037yandex.cloud.api.speechsense.v1B\027ClassifiersServiceProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsense'
  _globals['_CLASSIFIERSSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_CLASSIFIERSSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002%\" /speechsense/v1/classifiers/list:\001*'
  _globals['_LISTCLASSIFIERSREQUEST']._serialized_start=162
  _globals['_LISTCLASSIFIERSREQUEST']._serialized_end=206
  _globals['_LISTCLASSIFIERSRESPONSE']._serialized_start=208
  _globals['_LISTCLASSIFIERSRESPONSE']._serialized_end=295
  _globals['_CLASSIFIERSSERVICE']._serialized_start=298
  _globals['_CLASSIFIERSSERVICE']._serialized_end=479
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.cdn.v1 import resource_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2
from yandex.cloud.cdn.v1 import resource_service_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/cdn/v1/resource_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class ResourceServiceStub(object):
    """Provider's resources management service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.cdn.v1.ResourceService/Get',
                request_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__service__pb2.GetResourceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2.Resource.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/yandex.cloud.cdn.v1.ResourceService/List',
                request_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__service__pb2.ListResourcesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__service__pb2.ListResourcesResponse.FromString,
                _registered_method=True)
        self.Create = channel.unary_unary(
                '/yandex.cloud.cdn.v1.ResourceService/Create',
                request_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__service__pb2.CreateResourceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/yandex.cloud.cdn.v1.ResourceService/Update',
                request_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__service__pb2.UpdateResourceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Delete = channel.unary_unary(
                '/yandex.cloud.cdn.v1.ResourceService/Delete',
                request_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__service__pb2.DeleteResourceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.GetProviderCName = channel.unary_unary(
                '/yandex.cloud.cdn.v1.ResourceService/GetProviderCName',
                request_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__service__pb2.GetProviderCNameRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__service__pb2.GetProviderCNameResponse.FromString,
                _registered_method=True)


class ResourceServiceServicer(object):
    """Provider's resources management service.
    """

    def Get(self, request, context):
        """Get client's CDN resource by resource id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Lists CDN resources.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a CDN resource in the specified folder.

        Creation may take up to 15 minutes.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified CDN resource.

        The method implements patch behaviour, i.e. only the fields specified in the request are updated in the resource.

        Changes may take up to 15 minutes to apply. Afterwards, it is recommended to purge the resource's cache via a
        [CacheService.Purge] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes client's CDN resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProviderCName(self, request, context):
        """Get Provider's CNAME (edge endpoint) bind to specified folder id.
        Returns UNIMPLEMENTED error, if provider doesn't support CNAME request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ResourceServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__service__pb2.GetResourceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2.Resource.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__service__pb2.ListResourcesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__service__pb2.ListResourcesResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__service__pb2.CreateResourceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__service__pb2.UpdateResourceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__service__pb2.DeleteResourceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'GetProviderCName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProviderCName,
                    request_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__service__pb2.GetProviderCNameRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__service__pb2.GetProviderCNameResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.cdn.v1.ResourceService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.cdn.v1.ResourceService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ResourceService(object):
    """Provider's resources management service.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.cdn.v1.ResourceService/Get',
            yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__service__pb2.GetResourceRequest.SerializeToString,
            yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2.Resource.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.cdn.v1.ResourceService/List',
            yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__service__pb2.ListResourcesRequest.SerializeToString,
            yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__service__pb2.ListResourcesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.cdn.v1.ResourceService/Create',
            yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__service__pb2.CreateResourceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.cdn.v1.ResourceService/Update',
            yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__service__pb2.UpdateResourceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.cdn.v1.ResourceService/Delete',
            yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__service__pb2.DeleteResourceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetProviderCName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.cdn.v1.ResourceService/GetProviderCName',
            yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__service__pb2.GetProviderCNameRequest.SerializeToString,
            yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__service__pb2.GetProviderCNameResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/compute/v1/disk_placement_group_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/compute/v1/disk_placement_group_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.compute.v1 import disk_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_disk__pb2
from yandex.cloud.compute.v1 import disk_placement_group_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_disk__placement__group__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/compute/v1/disk_placement_group_service.proto\x12\x17yandex.cloud.compute.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a\"yandex/cloud/compute/v1/disk.proto\x1a\x32yandex/cloud/compute/v1/disk_placement_group.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"M\n\x1cGetDiskPlacementGroupRequest\x12-\n\x17\x64isk_placement_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xb8\x01\n\x1eListDiskPlacementGroupsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x86\x01\n\x1fListDiskPlacementGroupsResponse\x12J\n\x15\x64isk_placement_groups\x18\x01 \x03(\x0b\x32+.yandex.cloud.compute.v1.DiskPlacementGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xd9\x04\n\x1f\x43reateDiskPlacementGroupRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x33\n\x04name\x18\x02 \x01(\tB%\xf2\xc7\x31!|[a-z]([-_a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x99\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x44.yandex.cloud.compute.v1.CreateDiskPlacementGroupRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x1d\n\x07zone_id\x18\x05 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12Y\n\x19spread_placement_strategy\x18\x06 \x01(\x0b\x32\x34.yandex.cloud.compute.v1.DiskSpreadPlacementStrategyH\x00\x12_\n\x1cpartition_placement_strategy\x18\x07 \x01(\x0b\x32\x37.yandex.cloud.compute.v1.DiskPartitionPlacementStrategyH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x1a\n\x12placement_strategy\x12\x04\xc0\xc1\x31\x01\"C\n CreateDiskPlacementGroupMetadata\x12\x1f\n\x17\x64isk_placement_group_id\x18\x01 \x01(\t\"\xa1\x03\n\x1fUpdateDiskPlacementGroupRequest\x12-\n\x17\x64isk_placement_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x33\n\x04name\x18\x03 \x01(\tB%\xf2\xc7\x31!|[a-z]([-_a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x99\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x44.yandex.cloud.compute.v1.UpdateDiskPlacementGroupRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"C\n UpdateDiskPlacementGroupMetadata\x12\x1f\n\x17\x64isk_placement_group_id\x18\x01 \x01(\t\"P\n\x1f\x44\x65leteDiskPlacementGroupRequest\x12-\n\x17\x64isk_placement_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"C\n DeleteDiskPlacementGroupMetadata\x12\x1f\n\x17\x64isk_placement_group_id\x18\x01 \x01(\t\"\x91\x01\n\"ListDiskPlacementGroupDisksRequest\x12-\n\x17\x64isk_placement_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"l\n#ListDiskPlacementGroupDisksResponse\x12,\n\x05\x64isks\x18\x01 \x03(\x0b\x32\x1d.yandex.cloud.compute.v1.Disk\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x96\x01\n\'ListDiskPlacementGroupOperationsRequest\x12-\n\x17\x64isk_placement_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"z\n(ListDiskPlacementGroupOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x95\x11\n\x19\x44iskPlacementGroupService\x12\xac\x01\n\x03Get\x12\x35.yandex.cloud.compute.v1.GetDiskPlacementGroupRequest\x1a+.yandex.cloud.compute.v1.DiskPlacementGroup\"A\x82\xd3\xe4\x93\x02;\x12\x39/compute/v1/diskPlacementGroups/{disk_placement_group_id}\x12\xa2\x01\n\x04List\x12\x37.yandex.cloud.compute.v1.ListDiskPlacementGroupsRequest\x1a\x38.yandex.cloud.compute.v1.ListDiskPlacementGroupsResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/compute/v1/diskPlacementGroups\x12\xcb\x01\n\x06\x43reate\x12\x38.yandex.cloud.compute.v1.CreateDiskPlacementGroupRequest\x1a!.yandex.cloud.operation.Operation\"d\xb2\xd2*6\n CreateDiskPlacementGroupMetadata\x12\x12\x44iskPlacementGroup\x82\xd3\xe4\x93\x02$\"\x1f/compute/v1/diskPlacementGroups:\x01*\x12\xe5\x01\n\x06Update\x12\x38.yandex.cloud.compute.v1.UpdateDiskPlacementGroupRequest\x1a!.yandex.cloud.operation.Operation\"~\xb2\xd2*6\n UpdateDiskPlacementGroupMetadata\x12\x12\x44iskPlacementGroup\x82\xd3\xe4\x93\x02>29/compute/v1/diskPlacementGroups/{disk_placement_group_id}:\x01*\x12\xe5\x01\n\x06\x44\x65lete\x12\x38.yandex.cloud.compute.v1.DeleteDiskPlacementGroupRequest\x1a!.yandex.cloud.operation.Operation\"~\xb2\xd2*9\n DeleteDiskPlacementGroupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02;*9/compute/v1/diskPlacementGroups/{disk_placement_group_id}\x12\xcf\x01\n\tListDisks\x12;.yandex.cloud.compute.v1.ListDiskPlacementGroupDisksRequest\x1a<.yandex.cloud.compute.v1.ListDiskPlacementGroupDisksResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/compute/v1/diskPlacementGroups/{disk_placement_group_id}/disks\x12\xe3\x01\n\x0eListOperations\x12@.yandex.cloud.compute.v1.ListDiskPlacementGroupOperationsRequest\x1a\x41.yandex.cloud.compute.v1.ListDiskPlacementGroupOperationsResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/compute/v1/diskPlacementGroups/{disk_placement_group_id}/operations\x12\xbf\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/compute/v1/diskPlacementGroups/{resource_id}:listAccessBindings\x12\xfe\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x96\x01\xb2\xd2*H\n access.SetAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02\x44\"?/compute/v1/diskPlacementGroups/{resource_id}:setAccessBindings:\x01*\x12\x8a\x02\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x9c\x01\xb2\xd2*K\n#access.UpdateAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02G\"B/compute/v1/diskPlacementGroups/{resource_id}:updateAccessBindings:\x01*Bb\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.disk_placement_group_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _globals['_GETDISKPLACEMENTGROUPREQUEST'].fields_by_name['disk_placement_group_id']._loaded_options = None
  _globals['_GETDISKPLACEMENTGROUPREQUEST'].fields_by_name['disk_placement_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTDISKPLACEMENTGROUPSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTDISKPLACEMENTGROUPSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTDISKPLACEMENTGROUPSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDISKPLACEMENTGROUPSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTDISKPLACEMENTGROUPSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDISKPLACEMENTGROUPSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTDISKPLACEMENTGROUPSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTDISKPLACEMENTGROUPSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTDISKPLACEMENTGROUPSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTDISKPLACEMENTGROUPSREQUEST'].fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATEDISKPLACEMENTGROUPREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEDISKPLACEMENTGROUPREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEDISKPLACEMENTGROUPREQUEST'].oneofs_by_name['placement_strategy']._loaded_options = None
  _globals['_CREATEDISKPLACEMENTGROUPREQUEST'].oneofs_by_name['placement_strategy']._serialized_options = b'\300\3011\001'
  _globals['_CREATEDISKPLACEMENTGROUPREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEDISKPLACEMENTGROUPREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEDISKPLACEMENTGROUPREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEDISKPLACEMENTGROUPREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071!|[a-z]([-_a-z0-9]{0,61}[a-z0-9])?'
  _globals['_CREATEDISKPLACEMENTGROUPREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEDISKPLACEMENTGROUPREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATEDISKPLACEMENTGROUPREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEDISKPLACEMENTGROUPREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_CREATEDISKPLACEMENTGROUPREQUEST'].fields_by_name['zone_id']._loaded_options = None
  _globals['_CREATEDISKPLACEMENTGROUPREQUEST'].fields_by_name['zone_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEDISKPLACEMENTGROUPREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEDISKPLACEMENTGROUPREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEDISKPLACEMENTGROUPREQUEST'].fields_by_name['disk_placement_group_id']._loaded_options = None
  _globals['_UPDATEDISKPLACEMENTGROUPREQUEST'].fields_by_name['disk_placement_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEDISKPLACEMENTGROUPREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEDISKPLACEMENTGROUPREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071!|[a-z]([-_a-z0-9]{0,61}[a-z0-9])?'
  _globals['_UPDATEDISKPLACEMENTGROUPREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEDISKPLACEMENTGROUPREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEDISKPLACEMENTGROUPREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEDISKPLACEMENTGROUPREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_DELETEDISKPLACEMENTGROUPREQUEST'].fields_by_name['disk_placement_group_id']._loaded_options = None
  _globals['_DELETEDISKPLACEMENTGROUPREQUEST'].fields_by_name['disk_placement_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTDISKPLACEMENTGROUPDISKSREQUEST'].fields_by_name['disk_placement_group_id']._loaded_options = None
  _globals['_LISTDISKPLACEMENTGROUPDISKSREQUEST'].fields_by_name['disk_placement_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTDISKPLACEMENTGROUPDISKSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDISKPLACEMENTGROUPDISKSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTDISKPLACEMENTGROUPDISKSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDISKPLACEMENTGROUPDISKSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTDISKPLACEMENTGROUPOPERATIONSREQUEST'].fields_by_name['disk_placement_group_id']._loaded_options = None
  _globals['_LISTDISKPLACEMENTGROUPOPERATIONSREQUEST'].fields_by_name['disk_placement_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTDISKPLACEMENTGROUPOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDISKPLACEMENTGROUPOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTDISKPLACEMENTGROUPOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDISKPLACEMENTGROUPOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_DISKPLACEMENTGROUPSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_DISKPLACEMENTGROUPSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002;\0229/compute/v1/diskPlacementGroups/{disk_placement_group_id}'
  _globals['_DISKPLACEMENTGROUPSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_DISKPLACEMENTGROUPSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002!\022\037/compute/v1/diskPlacementGroups'
  _globals['_DISKPLACEMENTGROUPSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_DISKPLACEMENTGROUPSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*6\n CreateDiskPlacementGroupMetadata\022\022DiskPlacementGroup\202\323\344\223\002$\"\037/compute/v1/diskPlacementGroups:\001*'
  _globals['_DISKPLACEMENTGROUPSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_DISKPLACEMENTGROUPSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*6\n UpdateDiskPlacementGroupMetadata\022\022DiskPlacementGroup\202\323\344\223\002>29/compute/v1/diskPlacementGroups/{disk_placement_group_id}:\001*'
  _globals['_DISKPLACEMENTGROUPSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_DISKPLACEMENTGROUPSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*9\n DeleteDiskPlacementGroupMetadata\022\025google.protobuf.Empty\202\323\344\223\002;*9/compute/v1/diskPlacementGroups/{disk_placement_group_id}'
  _globals['_DISKPLACEMENTGROUPSERVICE'].methods_by_name['ListDisks']._loaded_options = None
  _globals['_DISKPLACEMENTGROUPSERVICE'].methods_by_name['ListDisks']._serialized_options = b'\202\323\344\223\002A\022?/compute/v1/diskPlacementGroups/{disk_placement_group_id}/disks'
  _globals['_DISKPLACEMENTGROUPSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_DISKPLACEMENTGROUPSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002F\022D/compute/v1/diskPlacementGroups/{disk_placement_group_id}/operations'
  _globals['_DISKPLACEMENTGROUPSERVICE'].methods_by_name['ListAccessBindings']._loaded_options = None
  _globals['_DISKPLACEMENTGROUPSERVICE'].methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002B\022@/compute/v1/diskPlacementGroups/{resource_id}:listAccessBindings'
  _globals['_DISKPLACEMENTGROUPSERVICE'].methods_by_name['SetAccessBindings']._loaded_options = None
  _globals['_DISKPLACEMENTGROUPSERVICE'].methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*H\n access.SetAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002D\"?/compute/v1/diskPlacementGroups/{resource_id}:setAccessBindings:\001*'
  _globals['_DISKPLACEMENTGROUPSERVICE'].methods_by_name['UpdateAccessBindings']._loaded_options = None
  _globals['_DISKPLACEMENTGROUPSERVICE'].methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*K\n#access.UpdateAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002G\"B/compute/v1/diskPlacementGroups/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETDISKPLACEMENTGROUPREQUEST']._serialized_start=378
  _globals['_GETDISKPLACEMENTGROUPREQUEST']._serialized_end=455
  _globals['_LISTDISKPLACEMENTGROUPSREQUEST']._serialized_start=458
  _globals['_LISTDISKPLACEMENTGROUPSREQUEST']._serialized_end=642
  _globals['_LISTDISKPLACEMENTGROUPSRESPONSE']._serialized_start=645
  _globals['_LISTDISKPLACEMENTGROUPSRESPONSE']._serialized_end=779
  _globals['_CREATEDISKPLACEMENTGROUPREQUEST']._serialized_start=782
  _globals['_CREATEDISKPLACEMENTGROUPREQUEST']._serialized_end=1383
  _globals['_CREATEDISKPLACEMENTGROUPREQUEST_LABELSENTRY']._serialized_start=1310
  _globals['_CREATEDISKPLACEMENTGROUPREQUEST_LABELSENTRY']._serialized_end=1355
  _globals['_CREATEDISKPLACEMENTGROUPMETADATA']._serialized_start=1385
  _globals['_CREATEDISKPLACEMENTGROUPMETADATA']._serialized_end=1452
  _globals['_UPDATEDISKPLACEMENTGROUPREQUEST']._serialized_start=1455
  _globals['_UPDATEDISKPLACEMENTGROUPREQUEST']._serialized_end=1872
  _globals['_UPDATEDISKPLACEMENTGROUPREQUEST_LABELSENTRY']._serialized_start=1310
  _globals['_UPDATEDISKPLACEMENTGROUPREQUEST_LABELSENTRY']._serialized_end=1355
  _globals['_UPDATEDISKPLACEMENTGROUPMETADATA']._serialized_start=1874
  _globals['_UPDATEDISKPLACEMENTGROUPMETADATA']._serialized_end=1941
  _globals['_DELETEDISKPLACEMENTGROUPREQUEST']._serialized_start=1943
  _globals['_DELETEDISKPLACEMENTGROUPREQUEST']._serialized_end=2023
  _globals['_DELETEDISKPLACEMENTGROUPMETADATA']._serialized_start=2025
  _globals['_DELETEDISKPLACEMENTGROUPMETADATA']._serialized_end=2092
  _globals['_LISTDISKPLACEMENTGROUPDISKSREQUEST']._serialized_start=2095
  _globals['_LISTDISKPLACEMENTGROUPDISKSREQUEST']._serialized_end=2240
  _globals['_LISTDISKPLACEMENTGROUPDISKSRESPONSE']._serialized_start=2242
  _globals['_LISTDISKPLACEMENTGROUPDISKSRESPONSE']._serialized_end=2350
  _globals['_LISTDISKPLACEMENTGROUPOPERATIONSREQUEST']._serialized_start=2353
  _globals['_LISTDISKPLACEMENTGROUPOPERATIONSREQUEST']._serialized_end=2503
  _globals['_LISTDISKPLACEMENTGROUPOPERATIONSRESPONSE']._serialized_start=2505
  _globals['_LISTDISKPLACEMENTGROUPOPERATIONSRESPONSE']._serialized_end=2627
  _globals['_DISKPLACEMENTGROUPSERVICE']._serialized_start=2630
  _globals['_DISKPLACEMENTGROUPSERVICE']._serialized_end=4827
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.advanced_rate_limiter_profile_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetAdvancedRateLimiterProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADVANCED_RATE_LIMITER_PROFILE_ID_FIELD_NUMBER: builtins.int
    advanced_rate_limiter_profile_id: builtins.str
    """ID of the AdvancedRateLimiterProfile resource to return."""
    def __init__(
        self,
        *,
        advanced_rate_limiter_profile_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["advanced_rate_limiter_profile_id", b"advanced_rate_limiter_profile_id"]) -> None: ...

global___GetAdvancedRateLimiterProfileRequest = GetAdvancedRateLimiterProfileRequest

@typing.final
class ListAdvancedRateLimiterProfilesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder that the ARL profile belongs to.
    Currently page_size, page_token, filter and order_by are not supported and List method will return all ARL profiles in the folder.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id"]) -> None: ...

global___ListAdvancedRateLimiterProfilesRequest = ListAdvancedRateLimiterProfilesRequest

@typing.final
class ListAdvancedRateLimiterProfilesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADVANCED_RATE_LIMITER_PROFILES_FIELD_NUMBER: builtins.int
    @property
    def advanced_rate_limiter_profiles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.advanced_rate_limiter_profile_pb2.AdvancedRateLimiterProfile]:
        """List of AdvancedRateLimiterProfile resources.
        Currently next_page_token is not supported and List method will return all ARL profiles in the folder.
        """

    def __init__(
        self,
        *,
        advanced_rate_limiter_profiles: collections.abc.Iterable[yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.advanced_rate_limiter_profile_pb2.AdvancedRateLimiterProfile] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["advanced_rate_limiter_profiles", b"advanced_rate_limiter_profiles"]) -> None: ...

global___ListAdvancedRateLimiterProfilesResponse = ListAdvancedRateLimiterProfilesResponse

@typing.final
class CreateAdvancedRateLimiterProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ADVANCED_RATE_LIMITER_RULES_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a ARL profile in."""
    name: builtins.str
    """Name of the ARL profile. The name is unique within the folder. 1-50 characters long."""
    description: builtins.str
    """Optional description of the ARL profile."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels as `` key:value `` pairs. Maximum of 64 per resource."""

    @property
    def advanced_rate_limiter_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.advanced_rate_limiter_profile_pb2.AdvancedRateLimiterRule]:
        """List of rules."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        advanced_rate_limiter_rules: collections.abc.Iterable[yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.advanced_rate_limiter_profile_pb2.AdvancedRateLimiterRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["advanced_rate_limiter_rules", b"advanced_rate_limiter_rules", "description", b"description", "folder_id", b"folder_id", "labels", b"labels", "name", b"name"]) -> None: ...

global___CreateAdvancedRateLimiterProfileRequest = CreateAdvancedRateLimiterProfileRequest

@typing.final
class CreateAdvancedRateLimiterProfileMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADVANCED_RATE_LIMITER_PROFILE_ID_FIELD_NUMBER: builtins.int
    advanced_rate_limiter_profile_id: builtins.str
    """ID of the ARL profile that is being created."""
    def __init__(
        self,
        *,
        advanced_rate_limiter_profile_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["advanced_rate_limiter_profile_id", b"advanced_rate_limiter_profile_id"]) -> None: ...

global___CreateAdvancedRateLimiterProfileMetadata = CreateAdvancedRateLimiterProfileMetadata

@typing.final
class UpdateAdvancedRateLimiterProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ADVANCED_RATE_LIMITER_PROFILE_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ADVANCED_RATE_LIMITER_RULES_FIELD_NUMBER: builtins.int
    advanced_rate_limiter_profile_id: builtins.str
    """ID of the ARL profile to update."""
    name: builtins.str
    """Name of the ARL profile. The name is unique within the folder. 1-50 characters long."""
    description: builtins.str
    """Optional description of the ARL profile."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the AdvancedRateLimiterProfile resource are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels as `` key:value `` pairs. Maximum of 64 per resource."""

    @property
    def advanced_rate_limiter_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.advanced_rate_limiter_profile_pb2.AdvancedRateLimiterRule]:
        """List of rules."""

    def __init__(
        self,
        *,
        advanced_rate_limiter_profile_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        advanced_rate_limiter_rules: collections.abc.Iterable[yandex.cloud.smartwebsecurity.v1.advanced_rate_limiter.advanced_rate_limiter_profile_pb2.AdvancedRateLimiterRule] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["advanced_rate_limiter_profile_id", b"advanced_rate_limiter_profile_id", "advanced_rate_limiter_rules", b"advanced_rate_limiter_rules", "description", b"description", "labels", b"labels", "name", b"name", "update_mask", b"update_mask"]) -> None: ...

global___UpdateAdvancedRateLimiterProfileRequest = UpdateAdvancedRateLimiterProfileRequest

@typing.final
class UpdateAdvancedRateLimiterProfileMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADVANCED_RATE_LIMITER_PROFILE_ID_FIELD_NUMBER: builtins.int
    advanced_rate_limiter_profile_id: builtins.str
    """ID of the AdvancedRateLimiterProfile resource that is being updated."""
    def __init__(
        self,
        *,
        advanced_rate_limiter_profile_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["advanced_rate_limiter_profile_id", b"advanced_rate_limiter_profile_id"]) -> None: ...

global___UpdateAdvancedRateLimiterProfileMetadata = UpdateAdvancedRateLimiterProfileMetadata

@typing.final
class DeleteAdvancedRateLimiterProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADVANCED_RATE_LIMITER_PROFILE_ID_FIELD_NUMBER: builtins.int
    advanced_rate_limiter_profile_id: builtins.str
    """ID of the ARL profile to delete."""
    def __init__(
        self,
        *,
        advanced_rate_limiter_profile_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["advanced_rate_limiter_profile_id", b"advanced_rate_limiter_profile_id"]) -> None: ...

global___DeleteAdvancedRateLimiterProfileRequest = DeleteAdvancedRateLimiterProfileRequest

@typing.final
class DeleteAdvancedRateLimiterProfileMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADVANCED_RATE_LIMITER_PROFILE_ID_FIELD_NUMBER: builtins.int
    advanced_rate_limiter_profile_id: builtins.str
    """ID of the AdvancedRateLimiterProfile resource that is being deleted."""
    def __init__(
        self,
        *,
        advanced_rate_limiter_profile_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["advanced_rate_limiter_profile_id", b"advanced_rate_limiter_profile_id"]) -> None: ...

global___DeleteAdvancedRateLimiterProfileMetadata = DeleteAdvancedRateLimiterProfileMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.billing.v1.customer_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class CustomerServiceStub:
    """A set of methods for managing Customer resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.billing.v1.customer_service_pb2.ListCustomersRequest,
        yandex.cloud.billing.v1.customer_service_pb2.ListCustomersResponse,
    ]
    """Retrieves the list of customers associated with the specified reseller."""

    Invite: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.billing.v1.customer_service_pb2.InviteCustomerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Invites customer to the specified reseller."""

    CreateResellerServed: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.billing.v1.customer_service_pb2.CreateResellerServedCustomerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates new reseller-served customer."""

    Activate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.billing.v1.customer_service_pb2.ActivateCustomerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Activates specified customer. After customer is activated, he can use resources associated with his billing account."""

    Suspend: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.billing.v1.customer_service_pb2.SuspendCustomerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Suspend specified customer. After customer is suspended, he can't use resources associated with his billing account."""

class CustomerServiceAsyncStub:
    """A set of methods for managing Customer resources."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.billing.v1.customer_service_pb2.ListCustomersRequest,
        yandex.cloud.billing.v1.customer_service_pb2.ListCustomersResponse,
    ]
    """Retrieves the list of customers associated with the specified reseller."""

    Invite: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.billing.v1.customer_service_pb2.InviteCustomerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Invites customer to the specified reseller."""

    CreateResellerServed: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.billing.v1.customer_service_pb2.CreateResellerServedCustomerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates new reseller-served customer."""

    Activate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.billing.v1.customer_service_pb2.ActivateCustomerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Activates specified customer. After customer is activated, he can use resources associated with his billing account."""

    Suspend: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.billing.v1.customer_service_pb2.SuspendCustomerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Suspend specified customer. After customer is suspended, he can't use resources associated with his billing account."""

class CustomerServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Customer resources."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.billing.v1.customer_service_pb2.ListCustomersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.billing.v1.customer_service_pb2.ListCustomersResponse, collections.abc.Awaitable[yandex.cloud.billing.v1.customer_service_pb2.ListCustomersResponse]]:
        """Retrieves the list of customers associated with the specified reseller."""

    @abc.abstractmethod
    def Invite(
        self,
        request: yandex.cloud.billing.v1.customer_service_pb2.InviteCustomerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Invites customer to the specified reseller."""

    @abc.abstractmethod
    def CreateResellerServed(
        self,
        request: yandex.cloud.billing.v1.customer_service_pb2.CreateResellerServedCustomerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates new reseller-served customer."""

    @abc.abstractmethod
    def Activate(
        self,
        request: yandex.cloud.billing.v1.customer_service_pb2.ActivateCustomerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Activates specified customer. After customer is activated, he can use resources associated with his billing account."""

    @abc.abstractmethod
    def Suspend(
        self,
        request: yandex.cloud.billing.v1.customer_service_pb2.SuspendCustomerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Suspend specified customer. After customer is suspended, he can't use resources associated with his billing account."""

def add_CustomerServiceServicer_to_server(servicer: CustomerServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
